fnss.topologies.parsers.parse_inet — FNSS 0.1.0 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.0 documentation »
- API Reference »
- Functions »

# fnss.topologies.parsers.parse_inet

`parse_inet`(path)

  Parse a topology from an output file generated by the Inet topology generator

  Parameters : | path : str The path to the Inet output file
  Returns : | topology : Topology

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.0 documentation »
- API Reference »
- Functions »